Format

  • date: Date of capture

  • forklength: Fork length of catch in millimeters

  • weight: Weight of catch in grams

  • tag_code: Coded wire tag code

  • stream: River (Sacramento River)

  • site: Site of recapture (Knights Landing RST)

  • year: Year of recapture (Knights Landing RST)

  • julian_week: Week of recapture (Knights Landing RST)

  • run_year: Run year of recapture (where week >= 45 are year + 1)

  • week_index: Week index (aligns with btspasx model where week for is week 1, etc.)

  • release_group_id: Id variable created to group releases that have the same characteristics together. This can be used to join with the hatchery_release table.

rst_cwt_recaptures Table of recaptures from Knights Landing RST datasets