survival_model_inputs.RdAcoustic tagging data used to model survival for the SR JPE
survival_model_inputsfish_id: Unique identifier associated with each released fish
ch: Capture history of each fish describing detection at receiver location, 0 indicated not detected, 1 indicates detected
study_id: Unique identifier associated with each release group
fish_length: Fork length of fish in mm
fish_weight: Weight of fish in grams
fish_type: Type of fish used in release trial, typically indicated where that fish came from and species of fish
fish_release_date: Date of release
release_location: Location of release
year: Year of release
@source Central Valley Enhanced Acoustic Tagging Project.
This data package queries tagging data from many studies using the ERDDAP data server.
See data-raw/pull_acoustic_tagging_data.R for more details.