Format

  • stream: Stream

  • site: RST monitoring site

  • run_year: Run year (week >= 45 is included in the following calendar year; e.g. Dec 1995 would be included in run_year 1996)

  • number_weeks: Number of weeks sampled in the run_year, for reference

  • exclusion_type: Provides the exclusion ruleset applied

  • apply_to: Differentiates between years that can be excluded broadly ("all runs") or those specific to spring run ("spring")

years_to_exclude_rst_data Years for RST data that were identified as incomplete and not used in modeling datasets