hatchery_release.Rdrelease_location_name: Name of the location where fish were released (COLEMAN NFH, BATTLE CREEK BELOW CNFH, BATTLE CREEK NFK WILDCAT, BALDWIN CONST. YARD, SAC R LAKE REDDING PARK, SAC R BEL RBDD, SAC R RED BLUFF DIV DAM, SAC R COLUSA TO RBDD, SAC R BONNYVIEW BOAT RAMP, SAC R AT BUTTE CITY)
hatchery_location_name: Name of hatchery fish were sourced from.
species: Species of fish released ("chinook salmon")
run: Run of fish released ("fall", "late fall", "spring", "winter")
avg_weight: Average weight of fish released
avg_length: Average length of fish released
first_release_date: First date of release. Typically first and last release date are the same though some releases happen over days/weeks
last_release_date: Last date of release
date_span: Number of days between the first and last release date
mid_release_date: Midpoint date between first and last release date
release_to_knights_landing_distance: Distance to Knights Landing (RST) site of recapture (river km) from release location
release_latitude: Latitude of the release location
release_longitude: Longitude of release location
release_group_id: Releases are grouped with other releases with same fish occurring on the same day but with different tag codes. Use this to join with RST recaptures.
group_total_marked_N: Total number of marked fish included in the release
group_total_unmarked_N: Total number of unmarked fish included in the release
group_total_release_N: Total number of fish released
group_mark_rate: Mark rate of fish released
month: Month of first release date used to join environmental covariates
year: Water year (Oct-Sep) of first release date used to join environmental covariates
water_year: Water year of release date (where month 10-12 are year + 1)
stream: Stream of release location (relevant to SR JPE streams, some may be NA) used for joining the covariates
exceedance_flow_year_type: Exceedance year type. This covariate is available in forecast_covariates (https://srjpe.github.io/SRJPEdata/articles/forecast_covariates.html)
monthly_max_flow: Monthly max flow. This covariate is available in forecast_covariates (https://srjpe.github.io/SRJPEdata/articles/forecast_covariates.html)
hatchery_release This table summarizes coded wire tag (CWT) data from release location to RST site of recapture (knights landing) by release group. Data source: Regional Mark Processing Center: https://www.rmpc.org/ datasets